/*==============================================================================*/
/*  Copyright (C) 2009-2016, Heartland Data inc. All Rights Reserved.           */
/*                                                                              */
/*  Title  :   Data Writing Driver                                              */
/*  EventID:   Insert Kernelinfo Test Point                                     */
/*  AppVer :   DT10 Ver11.XX`@                                                */
/*  FileID :   39C21                                                            */
/*  Version:   1.1                                                              */
/*  Author :   HLDC                                                             */
/*==============================================================================*/
/*==============================================================================*/
/*  Desc:   Header for File IO                                                  */
/*==============================================================================*/
#include <stdio.h>
#include <sys/types.h>
#include <fcntl.h>
#include <unistd.h>
#include <string.h>

static int dat_file = 0;
static int BusoutMode = 0;

struct DT10_DATA
{
	char tp_func;
	unsigned int addr;
	unsigned int dat;
	unsigned int size;
	unsigned char value[256];
};

#define TP_BusOut		'1'
#define TP_MemoryOutput	'2'

#define DT10_DRV		"/proc/dt10proc"

/*==============================================================================*/
/*  Macro:  BusOutModeSet                                                       */
/*  Desc:   0 => open file 1 => writing 2 => close file                         */
/*==============================================================================*/
#define BusOutModeSet(mode)	BusoutMode = mode

/*==============================================================================*/
/*  Func:   _TP_BusOut                                                          */
/*  Desc:   Called by Test Point                                                */
/*==============================================================================*/
void _TP_BusOut(unsigned int addr, unsigned int dat)
{
	struct DT10_DATA dt10_data;

	if (BusoutMode == 0) {
		dat_file = open(DT10_DRV, O_RDWR);
		if (dat_file <= 0) {
			printf("[DT10]%s open error.\n", DT10_DRV);
			return;
		}
		BusOutModeSet(1);
	}

	dt10_data.tp_func = TP_BusOut;
	dt10_data.addr = addr;
	dt10_data.dat = dat;

	write(dat_file, &dt10_data, sizeof(dt10_data));
}

/*==============================================================================*/
/*  Func:   _TP_MemoryOutput                                                    */
/*  Desc:   Called by Variable TestPoint                                        */
/*==============================================================================*/
void _TP_MemoryOutput(unsigned int addr, unsigned int dat, void *value, unsigned int size)
{
	struct DT10_DATA dt10_data;

	if (BusoutMode == 0) {
		dat_file = open(DT10_DRV, O_RDWR);
		if (dat_file <= 0) {
			printf("[DT10]%s open error.\n", DT10_DRV);
			return;
		}
		BusOutModeSet(1);
	}

	dt10_data.tp_func = TP_MemoryOutput;
	dt10_data.addr = addr;
	dt10_data.dat = dat;
	dt10_data.size = size;
	memcpy(dt10_data.value, value, size);

	write(dat_file, &dt10_data, sizeof(dt10_data));
}
